@@ -320,4 +320,4 @@ def raiseSessionContextCannotBeNone():
     raise Exception('Context cannot be None')
 
 def getNewJti():
-    return Serializer.newUuid()
+    return Serializer.newUuidAsString()
